/*
 * Project name:
     Button (Demonstration of using Button Library)
 * Copyright:
     (c) Mikroelektronika, 2009.
 * Revision History:
     20080930:
       - initial release;
     20090720
       - modified by Slavisa Zlatanovic;
     20120123:
       - modified for PIC18F45K22 (FJ);
 * Description:
     This program demonstrates usage on-board button as PORTD input.
     On every RD0 one-to-zero transition PORTB is inverted.
 * Test configuration:
     MCU:             PIC18F45K22
                      http://ww1.microchip.com/downloads/en/DeviceDoc/41412D.pdf
     Dev.Board:       PIC-Ready1 Board
                      http://www.mikroe.com/eng/products/view/305/pic-ready1-board/
     Oscillator:      HS-PLL 32.0000 MHz, 8.0000 MHz Crystal
     Ext. Modules:    EasyLED Board - ac:EasyLED
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/eng/products/view/7/mikroc-pro-for-pic/
 * NOTES:
     - None.
 */

bit oldstate;                                    // Old state flag

void main() {
  ANSELB = 0;                                    // Configure PORTB pins as digital
  ANSELD = 0;                                    // Configure PORTD pins as digital

  TRISD0_bit = 1;                                // set RD0 pin as input

  TRISB = 0x00;                                  // Configure PORTB as output
  LATB = 0x0F;                                   // Initial PORTB value

  oldstate = 0;

  do {
    if (Button(&PORTD, 0, 1, 1)) {               // Detect logical one
      oldstate = 1;                              // Update flag
    }
    if (oldstate && Button(&PORTD, 0, 1, 0)) {   // Detect one-to-zero transition
      LATB = ~LATB;                              // Invert PORTB
      oldstate = 0;                              // Update flag
    }
  } while(1);                                    // Endless loop
}